==> nextcloud-18.0.4.tgz: nextcloud/apps/firstrunwizard/l10n/hu.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Másolás vágólapra",
    "Copied!" : "Másolva.",
    "Not supported!" : "Nem támogatott.",
    "Press ⌘-C to copy." : "A másoláshoz nyomj ⌘-C-t.",
    "Press Ctrl-C to copy." : "A másoláshoz nyomj Ctrl-C-t.",
    "First run wizard" : "Első indíráskori varázsló",
    "Add your profile information! For example your email is needed to reset your password." : "Add meg a profil adataidat! Az e-mail címedre pédául jelszó visszaállításkor lehet szükség.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Add meg a profil információidat! Állíts be egy profilképet és teljes nevet az egyszerűbb azonosíthatóságért minden szolgáltatásban.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Add meg a profil információidat! Állítsd be a teljes neved az egyszerűbb azonosíthatóságért minden szolgáltatásban.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Add meg a profil információidat! Állítsd be egy profilképet az egyszerűbb azonosíthatóságért minden szolgáltatásban.",
    "About" : "Névjegy",
    "A welcome and introduction wizard for Nextcloud" : "Kezeld adataid és fájljaid ott, ahol te döntesz róluk",
    "Start using Nextcloud" : "A Nextcloud használatának kezdete",
    "Extend your cloud" : "A felhőd kiterjesztése",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "A Nextcloud alkalmazásból több mint 100 alkalmazásával testre szabhatod a felhődet: ",
    "Groupware apps like Calendar, Contacts, Mail" : "Csoportmunka alkalmazások mint Naptár, Névjegyek, Levelező",
    "Communication with Nextcloud Talk" : "Kommunikáció a Nextcloud Beszélgetés segítségével",
    "Collaboration apps for document editing" : "Együttműködési alkalmazások a dokumentum szerkesztéséhez",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Biztonsági és hozzáférési tulajdonságok, mint a kétfaktoros azonosítás, SSO és ransomware védelem.",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "Továbbá elérhető még zenelejátszó, jelszó kezelő, kanban alkalmazás, letöltés kezelő vagy jegyzet szerkesztő",
    "Browse the app store" : "Alkalmazás bolt böngészése",
    "Stay in sync" : "Maradj szinkronban",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud hozzáférést biztosít a fájljaidhoz bárhol is légy",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "A könnyen kezelhető desktop és mobil kliensünk elérhető az összes főbb platformon, ingyen!",
    "Get the apps to sync your files" : "Alkalmazások a fájljaid szinkronizálásához",
    "Desktop client" : "Asztali kliens",
    "Android app" : "Android alkalmazás",
    "iOS app" : "IOS alkalmazás",
    "Connect your desktop apps to %s" : "Csatlakoztasd az asztali alkalmazást a %s-hoz",
    "Connect your calendar" : "Kapcsolódás a naptárhoz",
    "Connect your contacts" : "Kapcsolódás a címjegyzékekhez",
    "Access files via WebDAV" : "A fájlok elérése WebDAV-protokoll segítségével",
    "Get help" : "Segítség kérése",
    "Get more information" : "További információk",
    "The Nextcloud documentation for home users:" : "A Nextcloud leírása otthoni felhasználók számára",
    "User manual" : "Felhasználói kézikönyv",
    "Admin manual" : "Rendszergazdai kézikönyv",
    "Developer manual" : "Fejlesztői kézikönyv",
    "You can also ask for help in our community support channels:" : "Segítséget is kérhetsz a közösségi támogatói oldalainkon:",
    "the Nextcloud forums" : "A Nextcloud fórumok",
    "the Nextcloud IRC chat channel on freenode.net" : "A Nextcloud IRC chat a freenode.net oldalon",
    "Start contributing" : "Közreműködés kezdése",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Szülséged lenne egy bizonyos fejlesztésre a Nextcloudban? Hibát találtál? Szeretnél segíteni a fordításban, támogatni vagy dokumentálni a Nextcloudot?",
    "Become part of the Community" : "Légy tagja a Közösségnek",
    "Enterprise support" : "Vállalati támogatás",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Ha a Nextcloudot rendszer működés kritikus környezetben futtatod nagy számú felhasználóval és nagy adatmennyiséggel, és szükséged van Nextcloud szakértők támogatásra, vállalati előfizetéssel levelező vagy telefonos támogatás vehető igénybe.",
    "Get enterprise support" : "Vállalati támogatás beszerzése",
    "A safe home for all your data" : "Egy biztonságos hely az adataidnak",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "A Nextcloud segítségével kézben tarthatod és felügyelheted az adataidat. Tárold dokumentumaidat, naptáradat, névjegyeidet és fotóidat a vállalatod szerverein, otthon, valamelyik szolgáltatónknál vagy egy adatközpontban amit ismersz.",
    "Host your data and files where you decide" : "Tárold az adataidat és fájljaidat ahol te döntesz róluk",
    "Open Standards and Interoperability" : "Nyílt szabványok és együttműködési képességek",
    "100%% Open Source & community-focused" : "100%% Nyílt forráskodú és közösségi",
    "Learn more about %s" : "Tudj meg többet a %s-ról",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "A %s hozzáférést biztosít a fájljaidhoz amikor csak akarod. A könnyen kezelhető desktop és mobil kliensünk ingyenesen elérhető az összes főbb platformon.",
    "Connect other apps to %s" : "Csatlakoztass más alkalmazást a %s-hoz",
    "Server address" : "Kiszolgálócím",
    "Copy link" : "Hivatkozás másolása",
    "Previous" : "Előző",
    "Next" : "Következő",
    "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "A szinkronizációs kliensek beállítása egy <a href=\"%s\">jelszó használatával</a>. Ezzel a módszerrel biztos lehetsz benne, hogy le tudod tiltani a hozzáférést ha elveszted azt az eszközt.",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "A szinkronizációs kliensek használatával hozzácsatlakozhatsz bármilyen egyéb alkalmazáshoz ami támogatja a WebDAV/CalDAV/CardDAV protokolokat a %s-hoz.",
    "App recommendation: Nextcloud Talk" : "Alkalmazásjavaslat: Nextcloud Beszélgetés"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.7.tgz: nextcloud/apps/firstrunwizard/l10n/hu.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Másolás vágólapra",
    "Copied!" : "Másolva.",
    "Not supported!" : "Nem támogatott.",
    "Press ⌘-C to copy." : "A másoláshoz nyomj ⌘-C-t.",
    "Press Ctrl-C to copy." : "A másoláshoz nyomj Ctrl-C-t.",
    "First run wizard" : "Első indíráskori varázsló",
    "Add your profile information! For example your email is needed to reset your password." : "Add meg a profil adataidat! Az e-mail címedre pédául jelszó visszaállításkor lehet szükség.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Add meg a profil információidat! Állíts be egy profilképet és teljes nevet az egyszerűbb azonosíthatóságért minden szolgáltatásban.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Add meg a profil információidat! Állítsd be a teljes neved az egyszerűbb azonosíthatóságért minden szolgáltatásban.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Add meg a profil információidat! Állítsd be egy profilképet az egyszerűbb azonosíthatóságért minden szolgáltatásban.",
    "Schedule work & meetings, synced with all your devices." : "Ütemezett munkáját és találkozóit, szinkronizálva az összes eszközén.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Tartsa egy helyen kollégáit és barátait, anélkül hogy kiszivárogtatná a személyes adataikat.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Egyszerű e-mail alkalmazás, amely szépen integrálódik a Fájlok, Névjegyek és Naptár alkalmazásba.",
    "About" : "Névjegy",
    "A welcome and introduction wizard for Nextcloud" : "Kezeld adataid és fájljaid ott, ahol te döntesz róluk",
    "Start using Nextcloud" : "A Nextcloud használatának kezdete",
    "Extend your cloud" : "A felhőd kiterjesztése",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "A Nextcloud alkalmazásból több mint 100 alkalmazásával testre szabhatod a felhődet: ",
    "Groupware apps like Calendar, Contacts, Mail" : "Csoportmunka alkalmazások mint Naptár, Névjegyek, Levelező",
    "Communication with Nextcloud Talk" : "Kommunikáció a Nextcloud Beszélgetés segítségével",
    "Collaboration apps for document editing" : "Együttműködési alkalmazások a dokumentum szerkesztéséhez",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Biztonsági és hozzáférési tulajdonságok, mint a kétfaktoros azonosítás, SSO és ransomware védelem.",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "Továbbá elérhető még zenelejátszó, jelszó kezelő, kanban alkalmazás, letöltés kezelő vagy jegyzet szerkesztő",
    "Browse the app store" : "Alkalmazás bolt böngészése",
    "Stay in sync" : "Maradj szinkronban",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud hozzáférést biztosít a fájljaidhoz bárhol is légy",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "A könnyen kezelhető desktop és mobil kliensünk elérhető az összes főbb platformon, ingyen!",
    "Get the apps to sync your files" : "Alkalmazások a fájljaid szinkronizálásához",
    "Desktop client" : "Asztali kliens",
    "Android app" : "Android alkalmazás",
    "iOS app" : "IOS alkalmazás",
    "Connect your desktop apps to %s" : "Csatlakoztasd az asztali alkalmazást a %s-hoz",
    "Connect your calendar" : "Kapcsolódás a naptárhoz",
    "Connect your contacts" : "Kapcsolódás a címjegyzékekhez",
    "Access files via WebDAV" : "A fájlok elérése WebDAV-protokoll segítségével",
    "Get help" : "Segítség kérése",
    "Get more information" : "További információk",
    "The Nextcloud documentation for home users:" : "A Nextcloud leírása otthoni felhasználók számára",
    "User manual" : "Felhasználói kézikönyv",
    "Admin manual" : "Rendszergazdai kézikönyv",
    "Developer manual" : "Fejlesztői kézikönyv",
    "You can also ask for help in our community support channels:" : "Segítséget is kérhetsz a közösségi támogatói oldalainkon:",
    "the Nextcloud forums" : "A Nextcloud fórumok",
    "the Nextcloud IRC chat channel on freenode.net" : "A Nextcloud IRC chat a freenode.net oldalon",
    "Start contributing" : "Közreműködés kezdése",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Szülséged lenne egy bizonyos fejlesztésre a Nextcloudban? Hibát találtál? Szeretnél segíteni a fordításban, támogatni vagy dokumentálni a Nextcloudot?",
    "Become part of the Community" : "Légy tagja a Közösségnek",
    "Enterprise support" : "Vállalati támogatás",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Ha a Nextcloudot rendszer működés kritikus környezetben futtatod nagy számú felhasználóval és nagy adatmennyiséggel, és szükséged van Nextcloud szakértők támogatásra, vállalati előfizetéssel levelező vagy telefonos támogatás vehető igénybe.",
    "Get enterprise support" : "Vállalati támogatás beszerzése",
    "A safe home for all your data" : "Egy biztonságos hely az adataidnak",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "A Nextcloud segítségével kézben tarthatod és felügyelheted az adataidat. Tárold dokumentumaidat, naptáradat, névjegyeidet és fotóidat a vállalatod szerverein, otthon, valamelyik szolgáltatónknál vagy egy adatközpontban amit ismersz.",
    "Host your data and files where you decide" : "Tárold az adataidat és fájljaidat ahol te döntesz róluk",
    "Open Standards and Interoperability" : "Nyílt szabványok és együttműködési képességek",
    "100%% Open Source & community-focused" : "100%% Nyílt forráskodú és közösségi",
    "Learn more about %s" : "Tudj meg többet a %s-ról",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "A %s hozzáférést biztosít a fájljaidhoz amikor csak akarod. A könnyen kezelhető desktop és mobil kliensünk ingyenesen elérhető az összes főbb platformon.",
    "Connect other apps to %s" : "Csatlakoztass más alkalmazást a %s-hoz",
    "Server address" : "Kiszolgálócím",
    "Copy link" : "Hivatkozás másolása",
    "Previous" : "Előző",
    "Next" : "Következő",
    "App recommendation: Nextcloud Talk" : "Alkalmazásjavaslat: Nextcloud Beszélgetés",
    "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "A szinkronizációs kliensek beállítása egy <a href=\"%s\">jelszó használatával</a>. Ezzel a módszerrel biztos lehetsz benne, hogy le tudod tiltani a hozzáférést ha elveszted azt az eszközt.",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "A szinkronizációs kliensek használatával hozzácsatlakozhatsz bármilyen egyéb alkalmazáshoz ami támogatja a WebDAV/CalDAV/CardDAV protokolokat a %s-hoz."
},
"nplurals=2; plural=(n != 1);");
